@@ -1,5 +1,6 @@
 import argparse
-from acpype.params import usage, epilog, MAXTIME, outTopols
+
+from acpype.params import MAXTIME, epilog, outTopols, usage
 
 
 def get_option_parser():
@@ -21,10 +22,18 @@ def get_option_parser():
         help="a basename for the project (folder and output files)",
     )
     parser.add_argument(
-        "-x", "--inpcrd", action="store", dest="inpcrd", help="amber inpcrd file name (always used with -p)",
+        "-x",
+        "--inpcrd",
+        action="store",
+        dest="inpcrd",
+        help="amber inpcrd file name (always used with -p)",
     )
     parser.add_argument(
-        "-p", "--prmtop", action="store", dest="prmtop", help="amber prmtop file name (always used with -x)",
+        "-p",
+        "--prmtop",
+        action="store",
+        dest="prmtop",
+        help="amber prmtop file name (always used with -x)",
     )
     parser.add_argument(
         "-c",
@@ -72,10 +81,18 @@ def get_option_parser():
         help="am1-bcc flag, sqm (default), divcon, mopac",
     )
     parser.add_argument(
-        "-k", "--keyword", action="store", dest="keyword", help="mopac or sqm keyword, inside quotes",
+        "-k",
+        "--keyword",
+        action="store",
+        dest="keyword",
+        help="mopac or sqm keyword, inside quotes",
     )
     parser.add_argument(
-        "-f", "--force", action="store_true", dest="force", help="force topologies recalculation anew",
+        "-f",
+        "--force",
+        action="store_true",
+        dest="force",
+        help="force topologies recalculation anew",
     )
     group.add_argument(
         "-d",
@@ -84,6 +101,14 @@ def get_option_parser():
         dest="debug",
         help="for debugging purposes, keep any temporary file created (not allowed with arg -w)",
     )
+    group.add_argument(
+        "-w",
+        "--verboseless",
+        action="store_false",
+        default=True,
+        dest="verboseless",
+        help="print nothing (not allowed with arg -d)",
+    )
     parser.add_argument(
         "-o",
         "--outtop",
@@ -94,7 +119,11 @@ def get_option_parser():
         help="output topologies: all (default), gmx, cns or charmm",
     )
     parser.add_argument(
-        "-z", "--gmx4", action="store_true", dest="gmx4", help="write RB dihedrals old GMX 4.0",
+        "-z",
+        "--gmx4",
+        action="store_true",
+        dest="gmx4",
+        help="write RB dihedrals old GMX 4.0",
     )
     parser.add_argument(
         "-t",
@@ -113,15 +142,11 @@ def get_option_parser():
         help="max time (in sec) tolerance for sqm/mopac, default is %i hours" % (MAXTIME // 3600),
     )
     parser.add_argument(
-        "-y", "--ipython", action="store_true", dest="ipython", help="start iPython interpreter",
-    )
-    group.add_argument(
-        "-w",
-        "--verboseless",
-        action="store_false",
-        default=True,
-        dest="verboseless",
-        help="print nothing (not allowed with arg -d)",
+        "-y",
+        "--ipython",
+        action="store_true",
+        dest="ipython",
+        help="start iPython interpreter",
     )
     parser.add_argument(
         "-g",
@@ -139,7 +164,11 @@ def get_option_parser():
         # NOTE: when solvent is present, gmx mdrun is not working, lack solvent topology
     )
     parser.add_argument(
-        "-l", "--sorted", action="store_true", dest="sorted", help="sort atoms for GMX ordering",
+        "-l",
+        "--sorted",
+        action="store_true",
+        dest="sorted",
+        help="sort atoms for GMX ordering",
     )
     parser.add_argument(
         "-j",
@@ -149,6 +178,10 @@ def get_option_parser():
         help="create improper dihedral parameters for chiral atoms in CNS",
     )
     parser.add_argument(
-        "-v", "--version", action="store_true", dest="version", help="Show the Acpype version and exit",
+        "-v",
+        "--version",
+        action="store_true",
+        dest="version",
+        help="Show the Acpype version and exit",
     )
     return parser
