@@ -1,7 +1,9 @@
-import os
 import math
+import os
 import subprocess as sub
+import sys
 from shutil import which
+
 from acpype.params import Pi
 
 
@@ -11,9 +13,10 @@ def find_bin(abin):
 
 def checkOpenBabelVersion():
     "check openbabel version"
-    import openbabel as obl
     import warnings
 
+    import openbabel as obl
+
     warnings.filterwarnings("ignore")
     return int(obl.OBReleaseVersion().replace(".", ""))
 
@@ -247,7 +250,10 @@ def job_pids_family(jpid):
 
 
 def _getoutput(cmd):
-    """to simulate commands.getoutput in order to work with python 2.6 up to 3.x"""
+    """
+    To simulate commands.getoutput
+    shell=True is necessary despite security issues
+    """
     out = sub.Popen(cmd, shell=True, stderr=sub.STDOUT, stdout=sub.PIPE).communicate()[0][:-1]
     return out.decode()
 
@@ -256,3 +262,18 @@ def while_replace(string):
     while "  " in string:
         string = string.replace("  ", " ")
     return string
+
+
+def set_for_pip(binaries):
+    # For pip package
+    if which(binaries["ac_bin"]) is None:
+        LOCAL_PATH = os.path.dirname(__file__)
+        if sys.platform == "linux":
+            os.environ["PATH"] += os.pathsep + LOCAL_PATH + "/amber21-11_linux/bin"
+            os.environ["AMBERHOME"] = LOCAL_PATH + "/amber21-11_linux/"
+            os.environ["LD_LIBRARY_PATH"] = LOCAL_PATH + "/amber21-11_linux/lib/"
+        elif sys.platform == "darwin":
+            os.environ["PATH"] += os.pathsep + LOCAL_PATH + "/amber21-11_os/bin"
+            os.environ["AMBERHOME"] = LOCAL_PATH + "/amber21-11_os/"
+            os.environ["LD_LIBRARY_PATH"] = LOCAL_PATH + "/amber21-11_os/lib/"
+            os.environ["DYLD_LIBRARY_PATH"] = LOCAL_PATH + "/amber21-11_os/lib/"
